@@ -135,7 +135,7 @@ def parse_arguments():
     args = parser.parse_args()
 
     if args.version:
-        print('compile-commands: 1.1.2')
+        print('compile-commands: 1.1.3')
         exit(0)
 
     if not args.dir and not args.file:
@@ -167,28 +167,33 @@ def dir_path(path):
         raise NotADirectoryError(path)
 
 
-def symlink_to_path(path):
-    if os.path.islink(path):
-        return os.readlink(path)
-    else:
-        return path
-
-
 def get_compile_dbs(dir):
+    # TODO:
+    # Replace this call by something that stop the recursion for a given directory
+    # once the file has been found (BFS)
+    # e.g:
+    #    .
+    #    ├── component1
+    #    │   ├── build_Release
+    #    │   │   └── compile_commands.json // TODO:
+    #    │   ├── build_Debug               // Add logic to be able to choose in between two CDB
+    #    │   │   └── compile_commands.json // that are on the same level
+    #    │   └── some_directory //visit because it could be a build directory
+    #    |       └── another_directory //do not visit
+    #    ...
     paths = list(glob2.glob(
         '{}/**/compile_commands.json'.format(dir), recursive=True))
 
     # Since we take into account symlinks we have to make sure the symlinks
     # doesn't resolve to a file that we already take into account
-    paths = list(set([symlink_to_path(os.path.abspath(p)) for p in paths]))
+    paths = list(set([os.path.realpath(os.path.abspath(p)) for p in paths]))
 
     # Make sure we don't take into account a file in the root directory
-    # if the file in the root directory is a symlink to a build folder
-    # it will still be taken into account as long as the build folder
+    # if the file in the root directory is a symlink to a build directory
+    # it will still be taken into account as long as the build directory
     # is inside the tree
-    paths = [p for p in paths if Path(
+    return [p for p in paths if Path(
         p).parent.parts[-1] != Path(dir).parts[-1]]
-    return paths
 
 
 def remove_files(data, files):
@@ -271,19 +276,26 @@ def filter_commands(data, regex, replacement):
 
 def main():
     args = parse_arguments()
+    start = time.time()
 
-    if not args.quiet:
-        start = time.time()
+    if args.dir:
+        args.dir = os.path.abspath(args.dir)
 
     if args.file:
         args.dir = str(Path(os.path.abspath(args.file)).parent)
-        with open(str(args.file), "r") as json_file:
-            data = json.load(json_file)
-    elif not args.merge:
-        with open(str('{}/compile_commands.json'.format(args.dir)), "r") as json_file:
-            data = json.load(json_file)
-    else:
+
+    data = []
+    if args.merge:
         data = merge_json_files(get_compile_dbs(args.dir))
+    else:
+        # if --merge is not set we use existing data inside the specified directory
+        filepath = '{}/compile_commands.json'.format(args.dir)
+        try:
+            with open(filepath, "r") as json_file:
+                data = json.load(json_file)
+        except:
+            print('{} not found. Did you forget --merge?'.format(filepath))
+            exit(2)
 
     compile_db = "{}/{}".format(remove_trailing(
         args.dir, "/"), args.output)
@@ -312,6 +324,8 @@ def main():
     if not args.allow_duplicates:
         data = [dict(t) for t in {tuple(d.items()) for d in data}]
 
+    overwrote = os.path.isfile(compile_db)
+
     if len(data) > 0:
         with open(str(compile_db), "w") as json_file:
             json.dump(data, json_file, indent=4, sort_keys=False)
@@ -321,9 +335,13 @@ def main():
 
     if not args.quiet:
         end = time.time()
+
         print(
-            "{} created with {} commands in {}s.".format(
-                compile_db, len(data), end - start
+            "{} {} with {} command(s) in {}s.".format(
+                compile_db,
+                'updated' if overwrote else 'created',
+                len(data),
+                round(end - start, 4)
             )
         )
 
